summaryrefslogtreecommitdiff
path: root/src/station.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/station.cpp')
-rw-r--r--src/station.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/station.cpp b/src/station.cpp
index 456862d38..0f2555ffb 100644
--- a/src/station.cpp
+++ b/src/station.cpp
@@ -182,7 +182,7 @@ void Station::MarkTilesDirty(bool cargo_change) const
}
/** Obtain the length of a platform
* @pre tile must be a railway station tile
* @param tile A tile that contains the platform in question
* @return The length of the platform
*/
@@ -210,7 +210,7 @@ uint Station::GetPlatformLength(TileIndex tile) const
/** Determines the REMAINING length of a platform, starting at (and including)
* the given tile.
* @param tile the tile from which to start searching. Must be a railway station tile
* @param dir The direction in which to search.
* @return The platform length
*/
@@ -218,7 +218,7 @@ uint Station::GetPlatformLength(TileIndex tile, DiagDirection dir) const
{
TileIndex start_tile = tile;
uint length = 0;
- assert(IsRailwayStationTile(tile));
+ assert(IsRailStationTile(tile));
assert(dir < DIAGDIR_END);
do {
@@ -182,7 +182,7 @@ void Station::MarkTilesDirty(bool cargo_change) const
}
/** Obtain the length of a platform
- * @pre tile must be a railway station tile
+ * @pre tile must be a rail station tile
* @param tile A tile that contains the platform in question
* @return The length of the platform
@@ -210,7 +210,7 @@ uint Station::GetPlatformLength(TileIndex tile) const
/** Determines the REMAINING length of a platform, starting at (and including)
* the given tile.
- * @param tile the tile from which to start searching. Must be a railway station tile
+ * @param tile the tile from which to start searching. Must be a rail station tile
* @param dir The direction in which to search.
* @return The platform length